.. image:: https://travis-ci.org/timcera/plottoolbox.svg?branch=master
    :target: https://travis-ci.org/timcera/plottoolbox
    :height: 20

.. image:: https://coveralls.io/repos/timcera/plottoolbox/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/plottoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/plottoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/plottoolbox

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/plottoolbox/

.. image:: http://img.shields.io/pypi/dd/plottoolbox.svg
    :alt: plottoolbox downloads
    :target: https://pypi.python.org/pypi/plottoolbox/
